import "./tasks/mapping.wdl" as mapping
import "./tasks/Dedup.wdl" as Dedup
import "./tasks/Realigner.wdl" as Realigner
import "./tasks/BQSR.wdl" as BQSR
import "./tasks/PoN.wdl" as PoN
  
workflow {{ project_name }} {
  String SENTIEON_INSTALL_DIR
  String SENTIEON_LICENSE

  String sample_id
  File? fastq_1
  File? fastq_2
  File? deduped_bam
  File? deduped_bam_index

  File regions
  File ref_dir
  String fasta
  File dbsnp_dir
  String dbsnp
  File dbmills_dir
  String db_mills

  String sentieon_docker
  String cluster_config
  String disk_size
  
  if (fastq_1!= "") {
    call mapping.mapping as fastq_mapping {
      input: 
      group=sample_id,
      sample=sample_id,
      fastq_1=fastq_1,
      fastq_2=fastq_2,
      SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
      SENTIEON_LICENSE=SENTIEON_LICENSE,
      pl="ILLUMINAL",
      fasta=fasta,
      ref_dir=ref_dir,
      docker=sentieon_docker,
      disk_size=disk_size,
      cluster_config=cluster_config
    }

    call Dedup.Dedup as fastq_Dedup {
      input:
      SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
      SENTIEON_LICENSE=SENTIEON_LICENSE,
      sorted_bam=fastq_mapping.sorted_bam,
      sorted_bam_index=fastq_mapping.sorted_bam_index,
      sample=sample_id,
      docker=sentieon_docker,
      disk_size=disk_size,
      cluster_config=cluster_config
    }

    call BQSR.BQSR as fastq_BQSR {
      input:
      SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
      SENTIEON_LICENSE=SENTIEON_LICENSE,
      fasta=fasta,
      ref_dir=ref_dir,
      deduped_bam=fastq_Dedup.realigner_bam,
      deduped_bam_index=fastq_Dedup.realigner_bam_index,
      db_mills=db_mills,
      dbmills_dir=dbmills_dir,
      dbsnp=dbsnp,
      dbsnp_dir=dbsnp_dir,
      docker=sentieon_docker,
      disk_size=disk_size,
      cluster_config=cluster_config
    }

    call PoN.PoN as fastq_PoN {
      input:
      SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
      SENTIEON_LICENSE=SENTIEON_LICENSE,
      fasta=fasta,
      ref_dir=ref_dir,
      regions=regions,
      normal_bam=fastq_BQSR.recaled_bam,
      normal_bam_index=fastq_BQSR.recaled_bam_index,
      docker=sentieon_docker,
      disk_size=disk_size,
      cluster_config=cluster_config
    }
  }
  
  if (deduped_bam!= "") {
    call BQSR.BQSR as bam_BQSR {
      input:
      SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
      SENTIEON_LICENSE=SENTIEON_LICENSE,
      fasta=fasta,
      ref_dir=ref_dir,
      deduped_bam=deduped_bam,
      deduped_bam_index=deduped_bam_index,
      db_mills=db_mills,
      dbmills_dir=dbmills_dir,
      dbsnp=dbsnp,
      dbsnp_dir=dbsnp_dir,
      docker=sentieon_docker,
      disk_size=disk_size,
      cluster_config=cluster_config
    }

    call PoN.PoN as bam_PoN {
      input:
      SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
      SENTIEON_LICENSE=SENTIEON_LICENSE,
      fasta=fasta,
      ref_dir=ref_dir,
      regions=regions,
      normal_bam=bam_BQSR.recaled_bam,
      normal_bam_index=bam_BQSR.recaled_bam_index,
      docker=sentieon_docker,
      disk_size=disk_size,
      cluster_config=cluster_config
    }
  }
}